CSS-style property inheritance for computed styles.
In CSS, some properties are inherited from parent to child by default
(notably color, font-size, and font-weight) while others are not
(spacing, border, opacity). This module provides resolve which applies
those rules between a parent and child ComputedStyle.
Functions
- resolve
- Resolve a child style against its parent by applying CSS inheritance rules.